#include <STC32G.H>
#include <intrins.h>
#include "../COMM/stc32_stc8_usb.h"
#include "seg_led.h"
#include "key.h"
#include "NOdefine.h"

void sys_init();

//USB调试及复位所需定义
char *USER_DEVICEDESC = NULL;
char *USER_PRODUCTDESC = NULL;
char *USER_STCISPCMD = "@STCISP#";                      //设置自动复位到ISP区的用户接口命令


/*
函数功能：定时器0定时初始化
入口参数：@
函数返回：
其他备注：

*/
void Timer0init()
{
	AUXR &= 0x7F;  //定时器时钟12T模式 默认就是
	TMOD &= 0xF0;  //设置定时器模式
	TH0 = 0xF8;  // 计算出24M时钟下1ms定时时间初始值
	TL0 = 0x30;
	ET0 = 1;  // 使能定时器中断
	TR0 = 1;   // 开始定时
}


void Delay_ms(int x)        //@24.000MHz
{
	unsigned long edata i;
	for(; x > 0; x--)
	{
		_nop_();
		_nop_();
		_nop_();
		i = 5998UL;
		while (i) i--;
	}
}

void main()
{
	sys_init();
	usb_init();  //USB初始化
	Timer0init();
	EA = 1;
	
	LED_DATA = 0x0F;
	LED3 = 0;
	
	while(1)
	{
		Delay_ms(10);
		KEY_Deal();
		if( KEY_ReadState(KEY32) == KEY_PRESS)
		{
			LED0 = 0;
		}
		else if( KEY_ReadState(KEY32) == KEY_LONGPRESS)
		{
			LED1 = 0;
		}
		else if( KEY_ReadState(KEY32) == KEY_RELAX)
		{
			LED_DATA = 0xFF;
		}
	}

}

/*
函数功能：定时器0中断执行函数
入口参数：@
函数返回：
其他备注：
*/
void Timer0_Isr(void) interrupt 1
{
	SEGLEDarr_show();
}


void sys_init()
{
    WTST = 0;  //设置程序指令延时参数，赋值为0可将CPU执行指令的速度设置为最快
    EAXFR = 1; //扩展寄存器(XFR)访问使能
    CKCON = 0; //提高访问XRAM速度

    P0M1 = 0x30;   P0M0 = 0x30;   //设置P0.4、P0.5为漏极开路(实验箱加了上拉电阻到3.3V)
    P1M1 = 0x32;   P1M0 = 0x32;   //设置P1.1、P1.4、P1.5为漏极开路(实验箱加了上拉电阻到3.3V), P1.1在PWM当DAC电路通过电阻串联到P2.3
    P2M1 = 0x3c;   P2M0 = 0x3c;   //设置P2.2~P2.5为漏极开路(实验箱加了上拉电阻到3.3V)，设置开漏模式需要断开PWM当DAC电路中的R2电阻
    P3M1 = 0x50;   P3M0 = 0x50;   //设置P3.4、P3.6为漏极开路(实验箱加了上拉电阻到3.3V)
    P4M1 = 0x3c;   P4M0 = 0x3c;   //设置P4.2~P4.5为漏极开路(实验箱加了上拉电阻到3.3V)
    P5M1 = 0x0c;   P5M0 = 0x0c;   //设置P5.2、P5.3为漏极开路(实验箱加了上拉电阻到3.3V)
    P6M1 = 0xff;   P6M0 = 0xff;   //设置为漏极开路(实验箱加了上拉电阻到3.3V)
    P7M1 = 0x00;   P7M0 = 0x00;   //设置为准双向口
}